import { NgModule } from '@angular/core';
import { PreloadAllModules, RouterModule, Routes } from '@angular/router';
import { AuthGuardService as AuthGuard } from './services/guards/auth-guard.service';
import { PatientsComponent } from './components/patients/patients.component';
import { TherapistGuardService as TherapistGuard } from './services/guards/therapist-guard.service';
import { SessionGuardService as SessionGuard } from './services/guards/session-guard.service';
import { GuardianGuardService as GuardianGuard } from './services/guards/guardian-guard.service';
import { PatientComponent } from './components/patient/patient.component';
import { PatientAddComponent } from './components/patient-add/patient-add.component';
import { SessionSearchComponent } from './components/session-search/session-search.component';
import { TimelineComponent } from './components/timeline/timeline.component';
import { SessionComponent } from './components/session/session.component';
import { SettingsComponent } from './components/settings/settings.component';
import { AccountComponent } from './components/settings/account/account.component';
import { OrganizationComponent } from './components/settings/organization/organization.component';
import { CaregiversComponent } from './components/settings/caregivers/caregivers.component';
import { AddCaregiverComponent } from './components/settings/add-caregiver/add-caregiver.component';
import { AddTherapistComponent } from './components/settings/add-therapist/add-therapist.component';
import { NetworkComponent } from './components/settings/network/network.component';
import { AddNetworkComponent } from './components/settings/add-network/add-network.component';
import { ChildComponent } from './components/settings/child/child.component';
import { GoalsComponent } from './components/goals/goals.component';
import { GoalComponent } from './components/goal/goal.component';
import { GoalAddComponent } from './components/goal-add/goal-add.component';
import { GoalEditComponent } from './components/goal-edit/goal-edit.component';
import { WorkoutsComponent } from './components/workouts/workouts.component';
import { DocumentsComponent } from './components/documents/documents.component';
import { NotificationComponent } from './components/settings/notification/notification.component';
import { SignUpComponent } from './components/signup/signup.component';
import { NotificationsComponent } from './components/notifications/notifications.component';
import { ForgotPasswordComponent } from './auth/forgot-password/forgot-password.component';
import { LeaderboardComponent } from './components/leaderboard/leaderboard.component';
import { AuditComponent } from './components/audit/audit.component';
import { VideoComponent } from './components/video/video.component';
import { CommunicationComponent } from './components/communication/communication.component';
import { RecipientsComponent } from './components/recipients/recipients.component';
import { ViewersComponent } from './components/viewers/viewers.component';
import { MessagesComponent } from './components/messages/messages.component';
import {CaptureComponent} from './components/capture/capture.component';
import {CallbackComponent} from './components/callback/callback.component';

const routes: Routes = [
  {
    path: 'auth',
    loadChildren: './auth/auth.module#AuthPageModule'
  },
  {
    path: 'forgot-password',
    component: ForgotPasswordComponent,
  },
  {
    path: 'callback',
    component: CallbackComponent,
  },
  {
    path: 'notifications',
    component: NotificationsComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'patients',
    component: PatientsComponent,
    canActivate: [AuthGuard, TherapistGuard]
  },
  {
    path: 'patients/add-patient',
    component: PatientAddComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'patients/search-session',
    component: SessionSearchComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'patient/:id',
    component: PatientComponent,
    canActivate: [AuthGuard, TherapistGuard],
  },
  {
    path: 'timeline',
    component: TimelineComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'patient/session/:session_id',
    component: SessionComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'settings',
    component: SettingsComponent,
    canActivate: [AuthGuard],
  },
  {
    path: 'settings/child/:child_id',
    component: ChildComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'settings/account',
    component: AccountComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'settings/organization',
    component: OrganizationComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'settings/caregivers',
    component: CaregiversComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'settings/add-caregiver',
    component: AddCaregiverComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'settings/add-therapist',
    component: AddTherapistComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'settings/network',
    component: NetworkComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'settings/add-network',
    component: AddNetworkComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'patient/:id/goals',
    component: GoalsComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'patient/:id/add-goal',
    component: GoalAddComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'patient/:id/goals/:goal_id',
    component: GoalComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'patient/:id/goals/:goal_id/edit',
    component: GoalEditComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'patient/:id/documents',
    component: DocumentsComponent,
  },
  {
    path: 'patient/:id/session/:session_id',
    component: SessionComponent,
    canActivate: [AuthGuard],
    canDeactivate: [SessionGuard]
  },
  {
    path: 'session/:session_id',
    component: SessionComponent,
    canActivate: [AuthGuard],
    canDeactivate: [SessionGuard]
  },
  {
    path: 'workouts/:patient_id',
    component: WorkoutsComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'communication',
    component: CommunicationComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'capture',
    component: CaptureComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'recipients',
    component: RecipientsComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'viewers',
    component: ViewersComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'video',
    component: VideoComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'video/:token/:roomName',
    component: VideoComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'messages',
    component: MessagesComponent,
    canActivate: [AuthGuard]
  },
  {
    path: '',
    redirectTo: '/auth',
    pathMatch: 'full'
  },
  {
    path: 'leaderboard',
    component: LeaderboardComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'audit',
    component: AuditComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'signup',
    component: SignUpComponent
  },
];

@NgModule({
  imports: [
    RouterModule.forRoot(routes, { preloadingStrategy: PreloadAllModules })
  ],
  exports: [RouterModule]
})
export class AppRoutingModule {}
