import {NgModule, Renderer2} from '@angular/core';
import { CommonModule } from '@angular/common';
import { BrowserModule } from '@angular/platform-browser';
import { RouteReuseStrategy } from '@angular/router';
import { HttpClientModule, HTTP_INTERCEPTORS } from '@angular/common/http';

import { IonicModule, IonicRouteStrategy } from '@ionic/angular';
import { SplashScreen } from '@ionic-native/splash-screen/ngx';
import { StatusBar } from '@ionic-native/status-bar/ngx';
import { Camera} from '@ionic-native/camera/ngx';
import { FileTransfer } from '@ionic-native/file-transfer/ngx';
import { EmailComposer } from '@ionic-native/email-composer/ngx';
import { PhotoViewer } from '@ionic-native/photo-viewer/ngx';
import { Clipboard } from '@ionic-native/clipboard/ngx';
import { PapaParseModule } from 'ngx-papaparse';
import { NgxSpinnerModule } from 'ngx-spinner';
import { NativeAudio } from '@ionic-native/native-audio/ngx';
// import { ngDialog } from 'ng-dialog';

import { AppComponent } from './app.component';
import { AppRoutingModule } from './app-routing.module';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { JwtHelperService } from '@auth0/angular-jwt';
import { AuthInterceptor } from './interceptors/auth-interceptor';
import { PatientsComponent } from './components/patients/patients.component';
import { PatientComponent } from './components/patient/patient.component';
import { PatientAddComponent } from './components/patient-add/patient-add.component';
import { SessionSearchComponent } from './components/session-search/session-search.component';
import { TimelineComponent } from './components/timeline/timeline.component';
import { SessionComponent } from './components/session/session.component';
import { SettingsComponent } from './components/settings/settings.component';
import { AccountComponent } from './components/settings/account/account.component';
import { OrganizationComponent } from './components/settings/organization/organization.component';
import { CaregiversComponent } from './components/settings/caregivers/caregivers.component';
import { AddCaregiverComponent } from './components/settings/add-caregiver/add-caregiver.component';
import { AddTherapistComponent } from './components/settings/add-therapist/add-therapist.component';
import { NetworkComponent } from './components/settings/network/network.component';
import { AddNetworkComponent } from './components/settings/add-network/add-network.component';
import { ChildComponent } from './components/settings/child/child.component';
import { ToolbarComponent } from './components/common/toolbar/toolbar.component';
import { MediaCapture } from '@ionic-native/media-capture/ngx';
import { SessionTagsComponent } from './components/session/session-tags/session-tags.component';
import { GoalsComponent } from './components/goals/goals.component';
import { GoalComponent } from './components/goal/goal.component';
import { GoalAddComponent } from './components/goal-add/goal-add.component';
import { ProgressRadialComponent } from './components/common/progress-radial/progress-radial.component';
import { ProgressInteractiveComponent } from './components/common/progress-interactive/progress-interactive.component';
import { HistoryCommentComponent } from './components/common/history-comment/history-comment.component';
import { PopoverMenuComponent } from './components/common/popover-menu/popover-menu.component';
import { GoalEditComponent } from './components/goal-edit/goal-edit.component';
import { ProgressPipe } from './components/common/progress.pipe';
import { WorkoutsComponent } from './components/workouts/workouts.component';
import { WorkoutNotificationComponent } from './components/common/workout-notification/workout-notification.component';
import { DocumentsComponent } from './components/documents/documents.component';
import { LeaderboardComponent } from './components/leaderboard/leaderboard.component';
import { AuditComponent } from './components/audit/audit.component';
import { SessionTypePipe } from './components/common/session-type.pipe';
import { SessionNotesComponent } from './components/session/session-notes/session-notes.component';
import { AgePipe } from './components/common/age.pipe';
import { NotificationComponent } from './components/settings/notification/notification.component';
import { SessionCompleteComponent } from './components/session/session-complete/session-complete.component';
import { SignUpComponent } from './components/signup/signup.component';
import { LoadingContentComponent } from './components/session/loading-content/loading-content.component';
import { SessionDraftComponent } from './components/session/session-draft/session-draft.component';
import { SessionViewAttachmentComponent } from './components/session/session-view-attachment/session-view-attachment.component';
import { NotificationsComponent } from './components/notifications/notifications.component';
import { NotificationCardComponent } from './components/notifications/notification-card/notification-card.component';
import { ExplainerComponent } from './components/notifications/explainer/explainer.component';
import { ForgotPasswordComponent  } from './auth/forgot-password/forgot-password.component';
import { FileChooser } from '@ionic-native/file-chooser/ngx';
import { IOSFilePicker } from '@ionic-native/file-picker/ngx';
import { FilePath } from '@ionic-native/file-path/ngx';
import { File } from '@ionic-native/file/ngx';
import { FileOpener } from '@ionic-native/file-opener/ngx';
import { SocialSharing } from '@ionic-native/social-sharing/ngx';
import { VideoComponent } from './components/video/video.component';
import { HEADER_OFFSET } from '@angular/core/src/render3/interfaces/view';
import { CommunicationComponent } from './components/communication/communication.component';
import { RecipientsComponent } from './components/recipients/recipients.component';
import { ViewersComponent } from './components/viewers/viewers.component';
import { MessagesComponent } from './components/messages/messages.component';
import { TwilioService } from 'src/app/services/twilio.service';
import { Html2canvasService } from 'src/app/services/html2canvas.service';
import { WebVideoComponent } from './components/session/web-video/web-video.component';
import { WelcomeScreenComponent } from './components/notifications/welcome-screen/welcome-screen.component';
import {CaptureComponent} from './components/capture/capture.component';
import {CallbackComponent} from './components/callback/callback.component';


/** Http interceptor providers */
export const httpInterceptorProviders = [
  { provide: HTTP_INTERCEPTORS, useClass: AuthInterceptor, multi: true },
];

@NgModule({
  declarations: [
    AppComponent,
    PatientsComponent,
    PatientComponent,
    PatientAddComponent,
    SessionSearchComponent,
    TimelineComponent,
    SessionComponent,
    SettingsComponent,
    AccountComponent,
    OrganizationComponent,
    CaregiversComponent,
    AddCaregiverComponent,
    AddTherapistComponent,
    NetworkComponent,
    AddNetworkComponent,
    ChildComponent,
    WorkoutsComponent,
    ToolbarComponent,
    SessionTagsComponent,
    SessionNotesComponent,
    GoalsComponent,
    GoalComponent,
    GoalAddComponent,
    ProgressRadialComponent,
    ProgressInteractiveComponent,
    HistoryCommentComponent,
    PopoverMenuComponent,
    GoalEditComponent,
    ProgressPipe,
    WorkoutNotificationComponent,
    DocumentsComponent,
    SessionTypePipe,
    AgePipe,
    NotificationComponent,
    SessionCompleteComponent,
    SignUpComponent,
    LoadingContentComponent,
    SessionDraftComponent,
    NotificationsComponent,
    NotificationCardComponent,
    ExplainerComponent,
    ForgotPasswordComponent,
    SessionViewAttachmentComponent,
    LeaderboardComponent,
    AuditComponent,
    VideoComponent,
    CommunicationComponent,
    CaptureComponent,
    RecipientsComponent,
    ViewersComponent,
    MessagesComponent,
    WebVideoComponent,
    WelcomeScreenComponent,
    CallbackComponent
  ],
  entryComponents: [
    PopoverMenuComponent,
    SessionTagsComponent,
    SessionNotesComponent,
    SessionCompleteComponent,
    LoadingContentComponent,
    ExplainerComponent,
    SessionDraftComponent,
    SessionViewAttachmentComponent,
    WebVideoComponent,
    WelcomeScreenComponent
  ],
  imports: [
    BrowserModule,
    CommonModule,
    IonicModule.forRoot(),
    FormsModule,
    ReactiveFormsModule,
    HttpClientModule,
    AppRoutingModule,
    PapaParseModule,
    NgxSpinnerModule,
  ],
  providers: [
    StatusBar,
    SplashScreen,
    { provide: RouteReuseStrategy, useClass: IonicRouteStrategy },
    JwtHelperService,
    httpInterceptorProviders,
    MediaCapture,
    Camera,
    // Disable tslint for FileTransfer
    // tslint:disable-next-line
    FileTransfer,
    File,
    FileOpener,
    FileChooser,
    IOSFilePicker,
    FilePath,
    EmailComposer,
    PhotoViewer,
    Clipboard,
    SocialSharing,
    TwilioService,
    Html2canvasService,
    NativeAudio,
      VideoComponent,
    // ngDialog
  ],
  bootstrap: [AppComponent]
})
export class AppModule {}
