import { Component, OnInit, OnDestroy } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { GoalService } from 'src/app/services/goal.service';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { UserService } from 'src/app/services/user.service';
import { NavController } from '@ionic/angular';
import { IGoal } from 'src/app/models/server/goal';

@Component({
  selector: 'app-goal-edit',
  templateUrl: './goal-edit.component.html',
  styleUrls: ['./goal-edit.component.scss'],
})
export class GoalEditComponent implements OnInit, OnDestroy {
  public goalForm: FormGroup;
  public patientId;
  public goalId;
  public routeSub;
  public goalTypes$;
  public goalSubscription;
  public actionSheetOptions = {
    header: 'Select Type',
    cssClass: 'custom-action-sheet'
  };

  constructor(
    private fb: FormBuilder,
    private goalService: GoalService,
    private route: ActivatedRoute,
    private userService: UserService,
    private nav: NavController
  ) { }

  ngOnInit() {
    this.goalForm = this.fb.group({
      name: [{ value: '', disabled: false }, Validators.required],
      type_id: [{ value: '', disabled: false }, Validators.required],
      description: [{ value: '', disabled: false }, Validators.required],
      patient_id: [{ value: '', disabled: false }]
    });

    this.routeSub = this.route.paramMap.subscribe((params: ParamMap) => {
      this.patientId = params.get('id');
      this.goalId = params.get('goal_id');
      this.goalForm.get('patient_id').setValue(this.patientId);
      this.goalSubscription = this.goalService.goal.subscribe((goal: IGoal) => {
        this.goalForm.get('name').setValue(goal.name);
        this.goalForm.get('type_id').setValue(goal.type_id);
        this.goalForm.get('description').setValue(goal.description);
      });
      this.goalService.getGoal(this.goalId);
    });

    this.goalTypes$ = this.goalService.getGoalTypes();
  }

  saveGoal() {
    this.goalSubscription = this.goalService.updateGoal(this.goalId, this.goalForm.value).subscribe((res) => {
      if (res && res.id) {
        this.nav.navigateForward(`patient/${this.patientId}/goals/${res.id}`);
      }
    });
  }

  ngOnDestroy() {
    if (this.goalSubscription) {
      this.goalSubscription.unsubscribe();
    }
    if (this.routeSub) {
      this.routeSub.unsubscribe();
    }
  }

}
