import { Component, OnInit, OnDestroy } from '@angular/core';
import { NavController } from '@ionic/angular';
import { UserService } from 'src/app/services/user.service';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { ToastService } from '../../services/toast.service';

@Component({
  selector: 'app-patient-add',
  templateUrl: './patient-add.component.html',
  styleUrls: ['./patient-add.component.scss'],
})
export class PatientAddComponent implements OnInit, OnDestroy {
  public pageTitle = 'Add New Patient';
  public patientForm: FormGroup;
  private patientSubscription: any;
  private routeSub: any;
  public patientId: any;
  public todayDate: string = new Date().toISOString();

  constructor(
    public userService: UserService,
    private fb: FormBuilder,
    private toastService: ToastService,
    private nav: NavController
  ) { }

  ngOnInit() {
    this.patientForm = this.fb.group({
      patientFirstName: ['', Validators.required],
      patientLastName: ['', Validators.required],
      patientDoB: ['', Validators.required],
      patientDiagnosis: [''],
      caregiverFirstName: ['', Validators.required],
      caregiverLastName: ['', Validators.required],
      caregiverEmail: ['',
        Validators.compose([Validators.maxLength(70),
          Validators.email,
          Validators.required])]
    });
  }

  addPatient() {
    const patientDoB = this.patientForm.value.patientDoB.substring(0, 10);
    const data = {
      email: this.patientForm.value.caregiverEmail,
      firstName: this.patientForm.value.caregiverFirstName,
      lastName: this.patientForm.value.caregiverLastName,
      patients: [{
        firstName: this.patientForm.value.patientFirstName,
        lastName: this.patientForm.value.patientLastName,
        dateOfBirth: patientDoB,
        diagnosis: this.patientForm.value.patientDiagnosis
      }],
      sendInvite: true,
      userType: 'GUARDIAN',
    };

    this.userService.addGuardian(data).subscribe(() => {
      this.toastService.presentToast(`New patient has been added and caregiver invited.`);
      setTimeout(() => {
        this.routeToHome();
      }, 2000);
    }, (err) => {
      if (err.error.error === 'User already exists') {
        this.toastService.presentToastTopWithClose(`Good news! This user is already in the system. If you need to resend an invite, please go back the previous screen.`);
      } else {
        this.toastService.presentToastTopWithClose(`Error adding new patient. Please try again or contact support.`);
      }
      console.log(JSON.stringify(err));
    });
  }

  routeToHome() {
    if (this.userService.isDoctor) {
      this.nav.navigateRoot([`/patients`]);
    } else {
      this.nav.navigateRoot(`/timeline`);
    }
  }

  ngOnDestroy() {
    if (this.patientSubscription) {
      this.patientSubscription.unsubscribe();
    }
    if (this.routeSub) {
      this.routeSub.unsubscribe();
    }
  }

}
