import { Component, OnInit, Input } from '@angular/core';
import { FormControl } from '@angular/forms';
import { ModalController, AlertController } from '@ionic/angular';
import { UserService } from 'src/app/services/user.service';

@Component({
  selector: 'app-session-notes',
  templateUrl: './session-notes.component.html',
  styleUrls: ['./session-notes.component.scss'],
})
export class SessionNotesComponent implements OnInit {
  @Input() session;
  public coaching_focus_notes: FormControl;
  public session_update_notes: FormControl;
  constructor(
    private modalCtrl: ModalController,
    public userService: UserService,
    private alertController: AlertController
  ) { }

  ngOnInit() {
    this.coaching_focus_notes = new FormControl(this.session.coaching_focus_notes);
    this.session_update_notes = new FormControl(this.session.session_update_notes);
  }

  async close() {
    if (this.coaching_focus_notes.value === null && this.session.coaching_focus_notes === null &&
      this.session_update_notes.value === null && this.session.session_update_notes === null) {
        this.modalCtrl.dismiss();
    }

    if (this.coaching_focus_notes.value === this.session.coaching_focus_notes &&
      this.session_update_notes.value === this.session.session_update_notes) {
        this.modalCtrl.dismiss();
    }

    const alert = await this.alertController.create({
      message: 'Your notes have not been saved. Do you wish to continue?',
      buttons: [
        {
          text: 'No',
          role: 'cancel',
          cssClass: 'secondary'
        }, {
          text: 'Yes',
          cssClass: 'dark',
          handler: () => {
            this.modalCtrl.dismiss();
          }
        }
      ]
    });

    if (this.coaching_focus_notes.value !== this.session.coaching_focus_notes ||
      this.session_update_notes.value !== this.session.session_update_notes) {
        await alert.present();
    }
  }

  save() {
    this.modalCtrl.dismiss({
      coaching_focus_notes: this.coaching_focus_notes.value,
      session_update_notes: this.session_update_notes.value,
      creator_name: this.session.creator_name,
      organization_name: this.session.organization_name
    });
  }

  clearNotes(noteType) {
    noteType === 'coaching' ? this.coaching_focus_notes.setValue('') : this.session_update_notes.setValue('');
  }

}
