import { Component, OnInit, Input, ViewChild } from '@angular/core';
import { NavParams, ModalController, IonSelect, Events } from '@ionic/angular';
import { SafeResourceUrl } from '@angular/platform-browser';
import { SessionService } from 'src/app/services/session.service';

@Component({
  selector: 'app-session-tags',
  templateUrl: './session-tags.component.html',
  styleUrls: ['./session-tags.component.scss'],
})
export class SessionTagsComponent implements OnInit {
  @ViewChild('categorySelect') categorySelect: IonSelect;
  @Input() thumbnailPath: SafeResourceUrl;
  safeThumbnailPath: SafeResourceUrl;
  category = '';
  specialties: string[] = [];
  tags: any[] = [];
  filteredTags: any[] = [];
  selectedTags: any[] = [];

  constructor(
    private navParams: NavParams,
    private sessionService: SessionService,
    private modalCtrl: ModalController,
    private events: Events
    ) {
    // this.safeThumbnailPath = JSON.parse(navParams.get('thumbnailPath')).changingThisBreaksApplicationSecurity;
    // console.log('SAFTE THUMBNAIL PATH', this.safeThumbnailPath);
  }

  ngOnInit() {
    this.categorySelect.open(new MouseEvent('click'));
    this.sessionService.getSpecialties().subscribe((res) => {
      this.processTags(res.specialties);
      this.filterTags(this.specialties[0]);
    });
  }

  categorySelected(e) {
    this.category = e.target.value;
  }

  processTags(specialties) {
    for (const s of specialties) {
      this.specialties.push(s.canonical_name);
      if (s.tags) {
        const tags = s.tags.map((tag) => {
          tag.specialty = s.canonical_name;
          return tag;
        });
        for (const t of tags) {
          this.tags.push(t);
        }
        this.tags = this.tags.map(tag => {
          tag.canonical_name = String(tag.canonical_name).toLowerCase();
          return tag;
        });
      }
    }
    // console.log(this.tags);
  }

  specialtySelected(e) {
    this.filterTags(e.target.value);
  }

  filterTags(specialty) {
    this.filteredTags = this.tags.filter((tag) => {
      return tag.specialty === specialty;
    });
  }

  tagSelected(tag) {
    if (this.selectedTags.includes(tag)) {
      for (let i = 0; i < this.selectedTags.length; i++) {
        if (this.selectedTags[i] === tag) {
          this.selectedTags.splice(i, 1);
        }
     }
    } else {
      this.selectedTags.push(tag);
    }
  }

  tagIsSelected(tag) {
    return this.selectedTags.includes(tag);
  }

  joinSelectedTags() {
    const finalizedTags = [];
    this.selectedTags.forEach((tag) => {
      finalizedTags.push(tag.id);
    });
    return finalizedTags;
  }

  done() {
    this.modalCtrl.dismiss({
      category: this.category,
      tags: this.joinSelectedTags()
    });
  }
}
