import { Component, OnInit } from '@angular/core';
import { UserService } from 'src/app/services/user.service';
import { MenuItem } from 'src/app/models/client/menuitem';
import { User } from 'src/app/models/Client';
import { FormControl } from '@angular/forms';
import { ActionSheetController } from '@ionic/angular';
import { Camera as CordovaCamera } from '@ionic-native/camera/ngx';
import { Plugins, CameraResultType, CameraSource } from '@capacitor/core';
const { Camera } = Plugins;
import { StateService } from 'src/app/services/state.service';
import { SpecialtyService } from 'src/app/services/specialty.service';
import { map } from 'rxjs/operators';

@Component({
  selector: 'app-account',
  templateUrl: './account.component.html',
  styleUrls: ['./account.component.scss'],
})
export class AccountComponent implements OnInit {
  public pageTitle = 'My Account';
  public userAccount: any;
  public user: User;
  public phoneNumber: FormControl;
  userMenu: MenuItem[];
  public attachmentLoading = false;
  public specialties = [];
  currentSpecialty = '';
  public actionSheetOptions = {
    header: 'Select Type',
    cssClass: 'custom-action-sheet'
  };

  constructor(
    public userService: UserService,
    private actionCtrl: ActionSheetController,
    private cordovaCam: CordovaCamera,
    private stateService: StateService,
    private specialtyService: SpecialtyService
  ) { }

  ngOnInit() {
    console.log(this.userService.user.specialty_id);
    this.user = this.userService.user;
    this.phoneNumber = new FormControl(this.user.phone_number);
    if (this.userService.isDoctor) {
      this.userMenu = [
        {
          title: this.user.name,
          icon: 'contact',
          editable: false
        },
        {
          title: this.user.email,
          icon: 'mail',
          editable: false
        },
        {
          title: this.user.organizations[0].name,
          icon: 'business',
          editable: false
        },
        {
          title: this.user.phone_number,
          label: 'phoneNumber',
          icon: 'call',
          editable: true
        },
        {
          title: '',
          label: 'Therapy Type',
          icon: 'grid'
        }
      ];
    } else {
      this.userMenu = [
        {
          title: this.user.name,
          icon: 'contact',
          editable: false
        },
        {
          title: this.user.phone_number,
          label: 'phoneNumber',
          icon: 'call',
          editable: true
        },
        {
          title: this.user.email,
          icon: 'mail',
          editable: false
        }
      ];
    }

    this.specialtyService.getSpecialties().subscribe((res) => {
      this.specialties = res.specialties;
      this.currentSpecialty = this.specialties.find(s => s.id === this.user.specialty_id).name;
    });

  }

  public updatePhoneNumber() {
    this.userService.updatePhoneNumber(this.phoneNumber.value).subscribe((res) => {
      console.log(res);
    });
  }

  async openAttachmentActionSheet() {
    const actionSheet = await this.actionCtrl.create({
      mode: 'ios',
      header: 'Add Profile Pic',
      subHeader: 'Please select one of the options below',
      cssClass: 'attachmentSheet',
      buttons: [
        {
          text: 'Take Photo',
          icon: 'camera',
          handler: () => {
            this.startPhotoCapture();
          }
        },
        {
          text: 'Camera Roll',
          icon: 'image',
          handler: () => {
            this.openPhotoLibrary();
          }
        },
        {
          text: 'Cancel',
          role: 'cancel',
          handler: () => {
            console.log('Cancel clicked');
          }
        }
      ]
    });
    await actionSheet.present();
  }

  addProfilePic(file: any, model: any) {
    console.log('ADDING PROFILE PIC', file, model);
    // Temporary Dislpay of Profile Pic
    this.user.picture = file.thumbnailPath;

    // let attachment: SessionAttachment;
    // if (model === 'MediaFile') {
    //   attachment = {
    //     path: this.sanitizer.bypassSecurityTrustResourceUrl(file.fullPath),
    //     mediaType: file.type,
    //     localUrl: file.localUrl,
    //     thumbnailPath: this.sanitizer.bypassSecurityTrustResourceUrl(file.fullPath),
    //     name: file.name,
    //     tags: [],
    //     isSelected: false,
    //     category: 'Default'
    //   };
    // } else if (model === 'CameraPhoto') {
    //   attachment = {
    //     path: this.sanitizer.bypassSecurityTrustResourceUrl(file.path),
    //     mediaType: 'Image',
    //     format: file.format,
    //     localUrl: file.webPath,
    //     thumbnailPath: this.sanitizer.bypassSecurityTrustResourceUrl(file.webPath),
    //     tags: [],
    //     isSelected: false,
    //     category: 'Default'
    //   };
    // }
    // this.openTagModal(attachment);

    this.attachmentLoading = true;
  }

  public updateSpecialty($event) {
    const id = $event.target.value;
    this.userService.updateSpecialty(id).subscribe(res => {
      this.userService.getUser(this.user.user_id).subscribe((r) => {
        this.userService.user = new User(r, this.user.token);
        this.user = this.userService.user;
        this.currentSpecialty = this.specialties.find(s => s.id === this.user.specialty_id).name;
        console.log(this.userService.user.specialty_id);
      });
    });
  }

  async startPhotoCapture() {
    const image = await Camera.getPhoto({
      quality: 90,
      allowEditing: false,
      resultType: CameraResultType.Uri,
      source: CameraSource.Camera
    });
    this.addProfilePic(image, 'CameraPhoto');
  }

  async openPhotoLibrary() {
    let mediaFileToUpload = {};
    if (this.stateService.getPlatform() === 'ios' || this.stateService.getPlatform() === 'android') {
      const selectedMedia = await this.cordovaCam.getPicture({
        sourceType: this.cordovaCam.PictureSourceType.PHOTOLIBRARY,
        destinationType: this.cordovaCam.DestinationType.FILE_URI,
        mediaType: this.cordovaCam.MediaType.ALLMEDIA
      });
      const pickedFile = selectedMedia;
      const resizedFile = pickedFile;
      const currentName = selectedMedia.substr(pickedFile.lastIndexOf('/') + 1);
      const resizedFileName = resizedFile.substr(resizedFile.lastIndexOf('/') + 1);
      mediaFileToUpload = {
        // sessionId: this.sessionId,
        videoName: currentName,
        thumbnailName: resizedFileName,
        videoPath: selectedMedia,
        thumbnailPath: selectedMedia,
        fullThumbnailPath: selectedMedia,
        duration: 0,
        videoType: undefined,
        createdAt: new Date(),
        updatedAt: new Date(),
        tags: [],
        isImage: false
      };
      console.log('CREATED FILE OBJ', mediaFileToUpload);
      this.addProfilePic(mediaFileToUpload, 'MediaFile');
    } else {
      // desktop implement file picker
    }
    // this.openTagModal(mediaFileToUpload);
  }

}
