import { Component, OnInit } from '@angular/core';
import { NavController } from '@ionic/angular';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { UserService } from 'src/app/services/user.service';
import { PatientService } from 'src/app/services/patient.service';
import { ToastService } from '../../../services/toast.service';
import { Patient } from 'src/app/models/Server';
import {map, tap} from 'rxjs/operators';

@Component({
  selector: 'app-add-caregiver',
  templateUrl: './add-caregiver.component.html',
  styleUrls: ['./add-caregiver.component.scss'],
})
export class AddCaregiverComponent implements OnInit {
  public pageTitle;
  public caregiverForm: FormGroup;
  public organization;

  constructor(
    private fb: FormBuilder,
    public userService: UserService,
    public patientService: PatientService,
    private toastService: ToastService,
    private nav: NavController
  ) { }

  ngOnInit() {
    this.pageTitle = 'Add Caregiver';
    this.caregiverForm = this.fb.group({
      caregiverFirstName: ['', Validators.required],
      caregiverLastName: ['', Validators.required],
      caregiverEmail: ['',
        Validators.compose([Validators.maxLength(70),
          Validators.email,
          Validators.required])]
    });

    this.userService.getNetwork().subscribe( (res) => {
      this.organization = res.organizations[0];
    });

  }

  saveCaregiver() {
    const data = {
          email: this.caregiverForm.value.caregiverEmail,
          firstName: this.caregiverForm.value.caregiverFirstName,
          lastName: this.caregiverForm.value.caregiverLastName,
          patients: []
        };


    const newUser = {
      patientId : this.patientService.currentPatient.value.id,
      first_name : this.patientService.currentPatient.value.first_name ,
      last_name : this.patientService.currentPatient.value.last_name,
      date_of_birth : this.patientService.currentPatient.value.date_of_birth,
      organizationId : this.organization.id
    };
    data.patients.push(newUser);

    this.userService.addGuardian(data).subscribe((val) => {
      this.toastService.presentToast('Thank you! The new user has been invited.');
      setTimeout(() => {
        this.nav.navigateForward([`/patient/` + this.patientService.currentPatient.value.id]);
      }, 1000);
    }, (resp) => {
      if (!!resp && !!resp.error && resp.error.error === 'User already exists') {
        this.toastService.presentToastTopWithClose(`Good news! This user is already in the system. If you need to resend an invite, please go back the previous screen.`);
      } else {
        this.toastService.presentToastTopWithClose(`Error adding new caregiver. Please try again or contact support.`);
      }
    });
  }
}
