import { Component, OnInit } from '@angular/core';
import { SessionService } from 'src/app/services/session.service';
import { takeUntil, switchMap } from 'rxjs/operators';
import { Unsubscriber } from '../common/unsubscriber';
import { NavController } from '@ionic/angular';
import { ActivatedRoute, NavigationExtras } from '@angular/router';
import { UserService } from 'src/app/services/user.service';
import { PatientService } from 'src/app/services/patient.service';
import { WorkoutService } from 'src/app/services/workout.service';
import { Session, Patient } from 'src/app/models/Server';
import * as moment from 'moment';
import { NotificationService } from 'src/app/services/notification.service';

@Component({
  selector: 'app-timeline',
  templateUrl: './timeline.component.html',
  styleUrls: ['./timeline.component.scss'],
})
export class TimelineComponent extends Unsubscriber implements OnInit {
  pageTitle = 'Timeline';
  showFab = true;
  sessions: any[] = [];
  fakeSessions: any[] = [{}, {}, {}];
  patient;
  patientId: string;
  sessionsLoading = false;
  patientName;
  notificationCount;
  chatMessageCount;

  constructor(
    private sessionService: SessionService,
    public userService: UserService,
    private route: ActivatedRoute,
    private nav: NavController,
    private patientService: PatientService,
    public workoutService: WorkoutService,
    public notificationService: NotificationService) {
    super();
   }

  ngOnInit() {
    this.sessionsLoading = true;
    this.patientService.currentPatient.pipe(
      switchMap((patient: Patient) => {
        if (patient && patient.id) {
          this.patient = patient;
          this.patientName = patient.first_name + ' ' + patient.last_name;

          if (this.userService.isDoctor) {
            this.pageTitle = 'Previous Posts';
            this.showFab = false;
          }
          return this.sessionService.getSessions(patient.id);
        } else {
          return this.sessionService.getSessions(this.patientService.patients.value[0].id);
        }
      }),
      takeUntil(this._unsubscriber)).subscribe((response: any) => {
        this.sessions = response.sessions;

        for (const s of this.sessions) {

          s.created_date = moment(s.created_date).format('MMMM DD, YYYY');

          const showThumbnails = [];

          if (s.thumbnail_urls) {
            for (const i of s.thumbnail_urls) {
              if (i !== null) {
                if (i.indexOf('jpg') !== -1) {
                  showThumbnails.push(i);
                } else {
                  showThumbnails.push('video');
                }
              }
            }
          }

          s.showThumbnails = showThumbnails;
        }

        this.sessionsLoading = false;
      });

    // Polling for new notifications
    // setInterval(()=> this.notificationService.loadUserNotifications(), 1000);

    this.notificationService.notificationCount.subscribe((val) => {
      this.notificationCount = val;
    });

    this.notificationService.chatMessageCount.subscribe((val) => {
      this.chatMessageCount = val;
    });


    // this.patientService.currentPatient.subscribe((patient: Patient) => {
    //   if (patient && patient.id) {
    //     this.patient = patient;

    //     if (this.userService.isDoctor) {
    //       this.pageTitle = 'Previous Sessions';
    //       this.showFab = false;
    //     }
    //     return this.sessionService.getSessions(patient.id);
    //   } else {
    //     return this.sessionService.getSessions(this.patientService.patients.value[0].id);
    //   }
    // });

    // this.route.paramMap.pipe(
    //   switchMap((params: ParamMap) => {
    //     this.patient = params.get('patient');
    //     this.patientId = params.get('id');
    //     const id = params.get('id');
    //     if (id) {
    //       if (this.userService.isDoctor) {
    //         this.pageTitle = 'Previous Sessions';
    //         this.showFab = false;
    //       }
    //       return this.sessionService.getSessions(id);
    //     } else {
    //       return this.sessionService.getSessions(this.patientService.patients.value[0].id);
    //     }
    //   }),
    //   takeUntil(this._unsubscriber)).subscribe((response: any) => {
    //     this.sessions = response.sessions;
    //     this.sessionsLoading = false;
    //   });
  }

  // ionViewWillEnter() {
  //   this.notificationService.getUserNotifications().subscribe((val) => {
  //     this.notificationCount = val.notifications.length;
  //   });
  // }

  addSession() {
    this.nav.navigateForward([`/patient/session/null`]);
  }

  onSessionSelected(session: Session) {
    this.nav.navigateForward([`/patient/session/${session.id}`]);
  }

  goToBottom(session: Session) {
    if (Number(session.comment_count) > 0) {
      const navigationExtras: NavigationExtras = {
          queryParams: {
              goToBottom: true
          }
      };

      this.nav.navigateForward([`/patient/session/${session.id}`], navigationExtras);
    }
  }

  formatTags(tagString) {
    if (tagString && tagString.length) {
      return tagString.toLowerCase().split(';').filter((item, index) => index < 4);
    } else {
      return [];
    }
  }

  like(session) {
    this.sessionService.postSessionReaction(session.id).pipe(
      takeUntil(this._unsubscriber)
    ).subscribe((val) => {
      const newCount = parseInt(session.reaction_count, 10) + 1;
      session.reaction_count = newCount;
    });
  }

  goToNotifications() {
    this.nav.navigateForward([`/notifications`]);
  }

  goToSearch(sessions) {
    this.nav.navigateForward([`/patients/search-session`], this.patient);
  }


}
