import * as moment from 'moment';

export interface ITherapistWeekOverWeekEntry {
    organizationId: string;
    organizationName: string;
    therapistId: string;
    therapistName: string;
    lastLogin: string;
    lastActivity: string;
    createdSessionsCountCollection: number[];
    sessionCommentCountCollection: number[];
    therapistViewCountCollection: number[];
    guardianViewCountCollection: number[];
    guardianCommentCountCollection: number[];
    guardianCommentAttachmentCountCollection: number[];
}

export class TherapistWeekOverWeekEntry implements ITherapistWeekOverWeekEntry {
    public organizationId: string;
    public organizationName: string;
    public therapistId: string;
    public therapistName: string;
    public lastLogin: string;
    public lastActivity: string;
    public createdSessionsCountCollection: number[];
    public sessionCommentCountCollection: number[];
    public therapistViewCountCollection: number[];
    public guardianViewCountCollection: number[];
    public guardianCommentCountCollection: number[];
    public guardianCommentAttachmentCountCollection: number[];

    fromJSON(json) {
      // tslint:disable-next-line: forin
      for (const propName in json) {
        this[propName] = json[propName];
      }
      return this;
    }

    get lastLoginStr(): string {
        return !!this.lastLogin ? moment(this.lastLogin).format('MM-DD-YYYY') : null;
    }

    get currentSessionsCount(): number {
      if (!this.createdSessionsCountCollection || this.createdSessionsCountCollection.length < 1) {
        return 0;
      }
      return this.createdSessionsCountCollection[0];
    }

    get previousSessionsCount(): number {
      if (!this.createdSessionsCountCollection || this.createdSessionsCountCollection.length < 2) {
        return 0;
      }
      return this.createdSessionsCountCollection[1];
    }

    get currentCommentCount(): number {
      if (!this.sessionCommentCountCollection || this.sessionCommentCountCollection.length < 1) {
        return 0;
      }
      return this.sessionCommentCountCollection[0];
    }

    get previousCommentCount(): number {
      if (!this.sessionCommentCountCollection || this.sessionCommentCountCollection.length < 2) {
        return 0;
      }
      return this.sessionCommentCountCollection[1];
    }

    get currentViewCount(): number {
      if (!this.therapistViewCountCollection || this.therapistViewCountCollection.length < 1) {
        return 0;
      }
      return this.therapistViewCountCollection[0];
    }

    get previousViewCount(): number {
      if (!this.therapistViewCountCollection || this.therapistViewCountCollection.length < 2) {
        return 0;
      }
      return this.therapistViewCountCollection[1];
    }

    get currentGuardianActivityCount(): number {
      let total = 0;
      if (!!this.guardianViewCountCollection && this.guardianViewCountCollection.length > 0) {
        total += Number(this.guardianViewCountCollection[0]);
      }
      if (!!this.guardianCommentCountCollection && this.guardianCommentCountCollection.length > 1) {
        total += Number(this.guardianCommentCountCollection[0]);
      }
      return total;
    }

    get previousGuardianActivityCount(): number {
      let total = 0;
      if (!!this.guardianViewCountCollection && this.guardianViewCountCollection.length > 0) {
        total += Number(this.guardianViewCountCollection[1]);
      }
      if (!!this.guardianCommentCountCollection && this.guardianCommentCountCollection.length > 1) {
        total += Number(this.guardianCommentCountCollection[1]);
      }
      return total;
    }
}
