import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import { Observable } from 'rxjs';
import { User } from '../models/Client';
import { Platform, NavController } from '@ionic/angular';
import { StateService } from 'src/app/services/state.service';

@Injectable({
  providedIn: 'root'
})
export class CommunicationService {
  public incomingCall = false;
  public incomingCallInfo = null;
  public startNewCall = false;
  public startNewMessage = true;
  public recipientIds: string[] = [];
  public recipientsAccessToken: any = [];

  constructor(
      private http: HttpClient,
      public stateService: StateService,
) { }

  public createNewCall(userIds: string[]) {
    this.startNewCall = true;
    this.recipientIds = userIds;
  }

  public setIncomingCall(callInfo) {
    this.incomingCall = true;
    this.incomingCallInfo = callInfo;
  }

  public getContacts(): Observable<any[]> {
    return this.http.get<any[]>(`${environment.API_URL}/api/video/contacts`);
  }

  public getToken() {
    return this.http.get<any>(`${environment.API_URL}/api/video/token`);
    console.log('getting token');
  }

  public getComposition() {
    return this.http.get<any>(`${environment.API_URL}/api/video/composition`);
    console.log('getting composition');
  }


  public startVideoCall() {
      return this.http.post<any>(`${environment.API_URL}/api/video/startcall`, this.recipientIds);
  }

  public getShortInviteURL(longURL: string) {
      return this.http.post<any>(`${environment.API_URL}/api/video/getshorturl`, { longURL });
  }


  public createMewMessage(userIds: string[]) {
    this.startNewMessage = true;
    this.recipientIds = userIds;
  }

  public startMessage() {
    return this.http.post<any>(`${environment.API_URL}/api/message/startmessage`, this.recipientIds);
  }

  public sendMessageNotification() {
    return this.http.post<any>(`${environment.API_URL}/api/message/sendmessagenotification`, this.recipientIds);
  }

  public getUserMessageToken() {
    return this.http.post<any>(`${environment.API_URL}/api/message/getusermessagetoken`, this.recipientIds);
  }

}
