import { Injectable, NgZone } from '@angular/core';
import { FileTransfer, FileTransferObject, FileUploadOptions, FileUploadResult } from '@ionic-native/file-transfer/ngx';
import { from, Observable, BehaviorSubject } from 'rxjs';
import { ToastService } from './toast.service';
import { StateService } from './state.service';
// import { FileTransferManager } from 'cordova-plugin-background-upload';

declare var FileTransferManager: any;

export class Media {

  public uri: string;
  public status: string;
  public zone: NgZone;
  public id: string;

  constructor(
    url: string,
    private _ngZone: NgZone
      ) {
    this.uri = url;
    this.status = 'uploading';
    this.zone = _ngZone;
    this.id = '' + Math.random().toString(36).substr(2, 5);
  }

  updateStatus(stat: string) {
    // in order to updates to propagate, we need be in angular zone
    // more info here:
    // https://www.joshmorony.com/understanding-zones-and-change-detection-in-ionic-2-angular-2/
    // example where updates are made in angular zone:
    // https://www.joshmorony.com/adding-background-geolocation-to-an-ionic-2-application/
    this.zone.run(() => {
      this.status = stat;
    });
  }

}


@Injectable({
  providedIn: 'root'
})
export class FileTransferService {

  private allMedia: Array < Media > = [];
  private uploadManager: any;
  public uploadComplete$: BehaviorSubject<string> = new BehaviorSubject(null);
  public uploadFailed$: BehaviorSubject<string> = new BehaviorSubject(null);

  constructor(
    private toast: ToastService,
    private stateService: StateService
  ) {
    const self = this;
    if ( this.stateService.getPlatform() !== 'web') {
      setTimeout(() => {
        self.uploadManager = FileTransferManager.init();

        self.uploadManager.on('success', (upload) => {
          console.log(JSON.stringify(upload));
          console.log('upload: ' + upload.id + ' has been completed successfully');
          console.log(upload.serverResponse);
          const correspondingMedia = self.getMediaWithId(upload.id);
          console.log(correspondingMedia.uri);
          this.uploadComplete$.next(upload.id);
          if (correspondingMedia) {
            correspondingMedia.updateStatus('uploaded successfully');
          }
        });

        self.uploadManager.on('progress', (upload) => {
          console.log('uploading: ' + upload.id + ' progress: ' + upload.progress + '%');
          const correspondingMedia = self.getMediaWithId(upload.id);
          if (correspondingMedia) {
            correspondingMedia.updateStatus('uploading: ' + upload.progress + '%');
          }
        });

        self.uploadManager.on('error', (uploadException) => {
          this.uploadFailed$.next(uploadException.id);
          this.toast.presentToast('file upload failed. please retry.');
          if (uploadException.id) {
            console.log('upload: ' + uploadException.id + ' has failed');
            const correspondingMedia = self.getMediaWithId(uploadException.id);
            if (correspondingMedia) {
              correspondingMedia.updateStatus('Error while uploading');
            }
          } else {
            console.error('uploadManager caught an error: ' + uploadException.error);
          }
        });
      }, 1000);
    }
  }

  private getMediaWithId(mediaId) {
    for (const media of this.allMedia) {
      if (media.id === mediaId) {
        return media;
      }
    }

    return null;
  }

  private cancelUpload(media: Media): void {
    this.uploadManager.removeUpload(media.id, res => {
      console.log('removeUpload result: ', res);
      media.updateStatus('Aborted');
    }, err => alert('Error removing upload'));
  }

  public uploadFile(awsResponse, ngZone) {
    const media = new Media(awsResponse.localFilePath, ngZone);
    this.allMedia.push(media);

    const options: any = {
      serverUrl: awsResponse.uploadUrl,
      filePath: awsResponse.localFilePath,
      fileKey: 'file',
      id: media.id,
      headers: {
      },
      parameters: awsResponse.fields
    };
    this.uploadManager.startUpload(options);
    return media.id;
  }

  // constructor(
  //   private fileTransfer: FileTransfer
  // ) { }

  // // use Ionic FileTransfer API to handle uploading of file from phone to S3
  // uploadFile(awsResponse): Observable<any> {
  //   console.log(awsResponse)
  //   // create the new file transfer object
  //   const activeFileTransfer = this.fileTransfer.create();

  //   const options: FileUploadOptions = {
  //     fileKey: 'file',
  //     fileName: awsResponse.filename,
  //     httpMethod: 'PUT',
  //     mimeType: awsResponse.mimeType,
  //     chunkedMode: false,
  //     headers: {
  //       'Content-Type': awsResponse.mimeType
  //     }
  //   };

  //   return new Observable(observer => {
  //     const abortController = new AbortController();
  //     const subscription = from(
  //       activeFileTransfer.upload(awsResponse.localFilePath, awsResponse.uploadUrl, options)
  //       ).subscribe(observer);

  //     return () => {
  //       abortController.abort();
  //       subscription.unsubscribe();
  //     }
  //   });

    // return from(activeFileTransfer.upload(awsResponse.localFilePath, awsResponse.uploadUrl, options)
    //   .then((evt) => {
    //     console.debug('UPLOAD COMPLETE');
    //     //this.finishUploadByCreatingAttachment(videoObj);
    //     //this.removeTransferById(transferId);
    //     //this.onFileTransferComplete(evt, upload);
    //   })
    //   .catch((err) => {
    //     console.error('UPLOAD ERROR', err);
    //     //this.removeTransferById(transferId);
    //     //this.onFileTransferError(err, upload);
    //   }));

  // }
}
