import { Injectable } from '@angular/core';
import { CanDeactivate } from '@angular/router';
import { ActionSheetController, NavController, ModalController } from '@ionic/angular';
import { UserService } from '../user.service';
import { SessionDraftComponent } from '../../components/session/session-draft/session-draft.component';
import { SessionComponent } from '../../components/session/session.component';
import { componentFactoryName } from '@angular/compiler';

@Injectable({
  providedIn: 'root'
})
export class SessionGuardService implements CanDeactivate<SessionComponent> {
  path;
  route;
  constructor(
    private userService: UserService,
    private modalCtrl: ModalController) { }

    async canDeactivate(component: SessionComponent) {
      if (this.userService.isDoctor && component.session.state === 'PENDING') {
        return this.showDraftModal(component.sessionId);
      }

      return true;
    }

    async showDraftModal(sessionId: string) {
      const modal = await this.modalCtrl.create({
        component: SessionDraftComponent,
        componentProps: {
          sessionId
        }
      });
      await modal.present();

      const { data } = await modal.onWillDismiss();
      return data.allow;
    }
}
