import { Injectable } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { GetUserResponse } from '../models/Http';
import { HttpClient } from '@angular/common/http';
import { StorageService } from './storage.service';
import { User } from '../models/client/User';
import { environment } from 'src/environments/environment';
import { UserType } from '../models/server/UserType';


@Injectable({
  providedIn: 'root'
})
export class UserService {

  previousUser: Subject<any> = new Subject<any>();
  user: User;
  constructor(private http: HttpClient, private storage: StorageService) { }

  public get userId(): string {
    return !!this.user ? this.user.user_id : null;
  }

  public updateSpecialty(specialty) {
    return this.http.put(`${environment.API_URL}/api/users/specialty`, {specialtyId: specialty});
  }

  public getUser(userId: string): Observable<GetUserResponse> {
    return this.http.get(`${environment.API_URL}/api/users/${userId}`);
  }

  public getUserByAuth0Id(auth0Id: string): Observable<GetUserResponse> {
    return this.http.get(`${environment.API_URL}/api/users/${auth0Id}?useAuth0Id=true`);
  }

  public get isDoctor(): boolean {
    if (this.user) {
      return this.user.hasRole('Doctor');
    }
  }

  public get isGuardian(): boolean {
    if (this.user) {
      return this.user.hasRole('Guardian');
    }
  }

  public async checkForPreviousUser() {
    const user = await this.storage.getObject('previousUser');
    this.previousUser.next(user);
  }

  public async setPreviousUser(user) {
    await this.storage.setObject('previousUser', user);
    this.previousUser.next(user);
  }

  public sendForgotPassword(email): Observable<any> {
    return this.http.post<any>(`${environment.API_URL}/api/users/forgot`, {email});
  }

  public addCaregiverWithFeedbackEmail(data) {
    const submitData = Object.assign({type: 'SUGGUARD'}, data);
    return this.http.post<any>(`${environment.API_URL}/api/feedback/suggest/SUGGUARD`, submitData);
  }

  public addTherapistWithFeedbackEmail(data) {
    const submitData = Object.assign({type: 'SUGDOC'}, data);
    return this.http.post<any>(`${environment.API_URL}/api/feedback/suggest/SUGDOC`, submitData);
  }

  public getNetwork() {
    return this.http.get<any>(`${environment.API_URL}/api/users/network`);
  }

  public addNetwork(data) {
    const submitData = Object.assign({type: 'SUGORG'}, data);
    return this.http.post<any>(`${environment.API_URL}/api/feedback/suggest/SUGORG`, submitData);
  }

  public addPatient(data) {
    const submitData = Object.assign({type: 'SUGCHILD'}, data);
    return this.http.post<any>(`${environment.API_URL}/api/feedback/suggest/SUGCHILD`, submitData);
  }

  public updatePhoneNumber(phoneNumber: string) {
    return this.http.put(`${environment.API_URL}/api/users/phonenumber`, {phoneNumber});
  }

  public registerDevice(deviceToken: string) {
    const url = environment.USE_DEV_NOTIFICATIONS ? `${environment.API_URL}/api/users/device-dev` : `${environment.API_URL}/api/users/device`;
    return this.http.post<any>(url, { deviceToken });
  }

  public registerVoipToken(voipToken: string) {
    const url = environment.USE_DEV_NOTIFICATIONS ? `${environment.API_URL}/api/users/registervoip-dev` : `${environment.API_URL}/api/users/registervoip`;
    return this.http.post<any>(url, { voipToken });
  }

  public addGuardian(data) {
    data.userType = UserType.Guardian;
    return this.http.post<any>(`${environment.API_URL}/api/users`, data);
  }

  public addTherapist(data) {
    data.userType = UserType.Therapist;
    return this.http.post<any>(`${environment.API_URL}/api/users`, data);
  }

  public sendResendInvite(user) {

    let data  = {};

    if (user.organization_id) {
      data = {
      organizationId: user.organization_id
      };
    } else {
      this.getNetwork().subscribe(val => {
        data = {
          organizationId: val.organizations[0].id
        };
      });
    }

    return this.http.post<any>(`${environment.API_URL}/api/users/${user.user_id}/reinvite`, data);
  }

 }
